@@ -92,6 +92,8 @@ from .usecases.traffic_sign_monitoring import TrafficSignMonitoringConfig
 from .usecases.crop_weed_detection import CropWeedDetectionConfig
 from .usecases.child_monitoring import ChildMonitoringConfig
 from .usecases.gender_detection import GenderDetectionConfig
+from .usecases.concrete_crack_detection import ConcreteCrackConfig, ConcreteCrackUseCase
+from .usecases.fashion_detection import FashionDetectionConfig, FashionDetectionUseCase
 
 # Use case implementations
 from .usecases import (
@@ -126,6 +128,7 @@ from .usecases import (
     ChildMonitoringUseCase,
     GenderDetectionUseCase,
     WeaponDetectionUseCase,
+    FashionDetectionUseCase
 )
 
 # Register use cases automatically
@@ -161,6 +164,8 @@ _crop_weed_detection = CropWeedDetectionUseCase()
 _child_monitoring = ChildMonitoringUseCase()
 _gender_detection = GenderDetectionUseCase()
 _weapon_tracking = WeaponDetectionUseCase()
+_concrete_crack_detection = ConcreteCrackUseCase()
+_fashion_detection = FashionDetectionUseCase()
 
 registry.register_use_case(_people_counting.category, _people_counting.name, PeopleCountingUseCase)
 registry.register_use_case(_customer_service.category, _customer_service.name, CustomerServiceUseCase)
@@ -195,6 +200,8 @@ registry.register_use_case(_solar_panel.category, _solar_panel.name, SolarPanelU
 registry.register_use_case(_crop_weed_detection.category, _crop_weed_detection.name, CropWeedDetectionUseCase)
 registry.register_use_case(_child_monitoring.category, _child_monitoring.name, ChildMonitoringUseCase)
 registry.register_use_case(_weapon_tracking.category, _weapon_tracking.name, WeaponDetectionUseCase)
+registry.register_use_case(_concrete_crack_detection.category, _concrete_crack_detection.name, ConcreteCrackUseCase)
+registry.register_use_case(_fashion_detection.category, _fashion_detection.name, FashionDetectionUseCase)
 
 # Utility functions - organized by category
 from .utils import (  # noqa: E402
@@ -358,6 +365,8 @@ __all__ = [
     'ChildMonitoringConfig',
     'GenderDetectionConfig',
     'WeaponDetectionConfig',
+    'ConcreteCrackConfig',
+    'FashionDetectionConfig',
 
     # Use case classes
     'PeopleCountingUseCase',
@@ -392,6 +401,8 @@ __all__ = [
     'CropWeedDetectionUseCase',
     'ChildMonitoringUseCase',
     'GenderDetectionUseCase',
+    'ConcreteCrackUseCase',
+    'FashionDetectionUseCase',
     
     # Base classes for extension
     'BaseProcessor',
