@@ -413,7 +413,7 @@ class ConfigManager:
             "emergency_vehicle_detection": None,
             "price_tag_detection": None,
             "child_monitoring": None,
-            "weapon_tracking" : None,
+            "weapon_detection" : None,
             "concrete_crack_detection": None,
             "fashion_detection": None,
         }
@@ -902,7 +902,7 @@ class ConfigManager:
                 **kwargs
             )
 
-        elif usecase == "weapon_tracking":
+        elif usecase == "weapon_detection":
             # Import here to avoid circular import
             from ..usecases.weapon_detection import WeaponDetectionConfig
 
@@ -1371,7 +1371,7 @@ class ConfigManager:
             default_config = TheftDetectionConfig()
             return default_config.to_dict()
         
-        elif usecase == "weapon_tracking":
+        elif usecase == "weapon_detection":
             # Import here to avoid circular import
             from ..usecases.weapon_detection import WeaponDetectionConfig
             default_config = WeaponDetectionConfig()
